pub enum SeqLoopMode {
Once,
Loop,
PingPong,
}Expand description
How the track behaves after the last keyframe has been reached.
Variants
Once
Play once and freeze on the last keyframe.
Loop
Wrap time back to the beginning and repeat.
PingPong
Bounce back and forth between first and last keyframe.