EmotionTimeline

Struct EmotionTimeline 

pub struct EmotionTimeline {
    pub keyframes: Vec<EmotionKeyframe>,
    pub duration: f32,
    pub loop_mode: TimelineLoop,
}
A keyframe-driven timeline of emotion weights.

Fields

keyframes: Vec<EmotionKeyframe>

Keyframes, always kept sorted by time.

duration: f32

Total duration in seconds.

loop_mode: TimelineLoop

How time is mapped past duration.

Implementations

Source

impl EmotionTimeline

pub fn new(duration: f32, loop_mode: TimelineLoop) -> Self

Create an empty timeline.

pub fn add_keyframe(&mut self, kf: EmotionKeyframe)

Insert a keyframe, keeping keyframes sorted by time.

pub fn sample(&self, t: f32) -> HashMap<String, f32>

Sample the emotion weights at an arbitrary time t.

pub fn bake(&self, fps: f32) -> Vec<HashMap<String, f32>>

Bake the timeline to a uniform frame sequence at fps frames per second. The returned vec has ceil(duration * fps) + 1 entries (inclusive of t=0 and t=duration).