pub struct ExprSequencer { /* private fields */ }Expand description
Combines multiple ExprTracks and evaluates them additively.
Implementations
Sourceimpl ExprSequencer
impl ExprSequencer
Sourcepub fn track_count(&self) -> usize
pub fn track_count(&self) -> usize
Number of tracks currently registered.
Sourcepub fn evaluate_all(&self, t: f32) -> ExprWeights
pub fn evaluate_all(&self, t: f32) -> ExprWeights
Evaluate all tracks at time t and blend additively.
When the same expression key appears in multiple tracks the weights are summed and then clamped to [0, 1].